<?php
namespace Forgood\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Forgood.
* @since 1.0.0
**/
class Fgood_Banner extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'fgood-banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Fgood Banner', 'forgood' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-post-title';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'forgood_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'forgood' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'forgood' ),
			]
		);

		$this->add_control(
			'banner-style',
			[
				'label' => __( 'Banner Style', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( 'Banner 1', 'forgood' ),
					'2' => __( 'Banner 2', 'forgood' ),
					'3' => __( 'Banner 3', 'forgood' ),
					'4' => __( 'Banner 4', 'forgood' ),
				],
			]
		);

		//banner 2 field
		$this->add_control(
			'enable_sticky', [
				'label'        => __( 'Enable Sticky Post', 'forgood' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'forgood' ),
				'label_off'    => __( 'Hide', 'forgood' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition' => [
					'banner-style' => '2',
				],
			]
		);
		$this->add_control(
			'select_post', [
				'label'     => esc_html__( 'Select Post', 'forgood' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => nextpage_core_select_post(),
				'condition' => [
					'enable_sticky' => [ 'yes' ],
					'banner-style' => '2',
				],
			]
		);
		$this->add_control(
			'banner-quote',
			[
				'label' => esc_html__( 'Banner Quote', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( "We're Near to Our Campaing", 'forgood' ),
				'condition' => [
					'banner-style' => '2',
				],
			]
		);

		//banner 3 field
		$this->add_control(
			'enable_sticky_3', [
				'label'        => __( 'Enable Sticky Post', 'forgood' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'forgood' ),
				'label_off'    => __( 'Hide', 'forgood' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition' => [
					'banner-style' => '3',
				],
			]
		);
		$this->add_control(
			'select_post_3', [
				'label'     => esc_html__( 'Select Post', 'forgood' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => nextpage_core_select_post(),
				'condition' => [
					'enable_sticky' => [ 'yes' ],
					'banner-style' => '3',
				],
			]
		);

		//banner 4 field
		$this->add_control(
			'enable_sticky_4', [
				'label'        => __( 'Enable Sticky Post', 'forgood' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'forgood' ),
				'label_off'    => __( 'Hide', 'forgood' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition' => [
					'banner-style' => '4',
				],
			]
		);
		$this->add_control(
			'select_post_4', [
				'label'     => esc_html__( 'Select Post', 'forgood' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => nextpage_core_select_post(),
				'condition' => [
					'enable_sticky' => [ 'yes' ],
					'banner-style' => '4',
				],
			]
		);
		$this->add_control(
			'banner-quote-4',
			[
				'label' => esc_html__( 'Banner Quote', 'forgood' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( "We're Near to Our </br> <span>Campaing</span>", 'forgood' ),
				'condition' => [
					'banner-style' => '4',
				],
			]
		);

		//banner 1 field
		$this->add_control(
			'banner-title',
			[
				'label' => esc_html__( 'Banner Title', 'forgood' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Add Your Banner title', 'forgood' ),
				'condition' => [
					'banner-style' => '1',
				],
			]
		);
		$this->add_control(
			'banner-content',
			[
				'label' => esc_html__( 'Banner Content', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Add Your Banner Content', 'forgood' ),
				'condition' => [
					'banner-style' => '1',
				],
			]
		);
		$this->add_control(
			'banner-video-text',
			[
				'label' => esc_html__( 'Banner Video Text', 'forgood' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Watching video', 'forgood' ),
				'condition' => [
					'banner-style' => '1',
				],
			]
		);
		$this->add_control(
			'banner-video-url',
			[
				'label' => esc_html__( 'Banner Video Url', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '#', 'forgood' ),
				'condition' => [
					'banner-style' => '1',
				],
			]
		);
		$this->add_control(
	   		'image', [
	          	'label' => esc_html__( 'Banner Background Image', 'forgood' ),
	          	'type'  => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
			   	],
	    	]
	    );
		$this->add_control(
			'banner-form',
			[
				'label' => __( 'banner Form', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
				'condition' => [
					'banner-style' => '1',
				],
			]
		);
		$this->end_controls_section();

		//banner style field
		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'forgood' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		//banner 1 color field
		$this->add_control(
			'video_color',
			[
				'label' => __( 'Video bg Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .banner-inner .video-play-btn' => 'background: {{VALUE}};',
				],
			]
		);

		//banner 4 color field
		$this->add_control(
			'video_color',
			[
				'label' => __( 'Video bg Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .banner-inner .video-play-btn' => 'background: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display(); 
		$images = $settings['image'];
		$image_id = $settings['image']['id'];
		$image_url = wp_get_attachment_image_src( $image_id, 'full', false ); ?>

		<?php if ($settings['banner-style'] == 2) { ?>
			<?php if ( $settings['enable_sticky'] == 'yes' ) : 
				$selected_post = new \WP_Query( array(
					'post_type'      => 'give_forms',
					'posts_per_page' => 1,
					'p'              => $settings['select_post']
				) );
				
				if ( $selected_post->have_posts() ) :
					while ( $selected_post->have_posts() ) : $selected_post->the_post(); 

						$img_id    = get_post_thumbnail_id( get_the_ID() );
						$src       = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full', false, '' );

						//give control here
						$form  = new \Give_Donate_Form( get_the_ID() );
		                $goal_progress_stats = give_goal_progress_stats( $form );
		                $income = $goal_progress_stats['raw_actual'];
		                $goal   = $goal_progress_stats['raw_goal'];
		                $progress           = $goal ? round( ( $income / $goal ) * 100, 2 ) : 0;
		                $progress_bar_values = $income >= $goal ? 100 : $progress;
		                $sales = $form->get_sales();
		                $sales = ( !empty($sales) ? $sales : 0 );

		                $progress_bar_value = (int)$progress_bar_values;

		                //currency control here
						$form_currency = apply_filters( 'give_goal_form_currency', give_get_currency( get_the_ID() ), get_the_ID() );
		                $income_format_args = apply_filters( 'give_goal_income_format_args', array(
		                    'sanitize' => false,
		                    'currency' => $form_currency,
		                    'decimal'  => false,
		                ), get_the_ID() );
		                $goal_format_args = apply_filters( 'give_goal_amount_format_args', array(
		                    'sanitize' => false,
		                    'currency' => $form_currency,
		                    'decimal'  => false,
		                ), get_the_ID() );
		                $income = give_human_format_large_amount( give_format_amount( $income, $income_format_args ), array( 'currency' => $form_currency ) );
		                $goal   = give_human_format_large_amount( give_format_amount( $goal, $goal_format_args ), array( 'currency' => $form_currency ) );
		                $fgood_raised = give_currency_filter( $income, array( 'form_id' => get_the_ID() ) );
		                $fgood_goal = give_currency_filter( $goal, array( 'form_id' => get_the_ID() ) );
						?>
						<div class="banner-area banner-area-2">
							<div class="thumb" style="background: url(<?php echo $src[0] ?>)"></div>
							<div class="banner-inner-wrap">
								<div class="container">
									<div class="banner-inner-wrap-details">
										<div class="row">
											<div class="col-md-6">
												<div class="details">
	                        						<h2><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
	                        						<?php
													//progress control content
													$give_content = get_post_meta(get_the_ID(), '_give_form_content', true);
				                    					$content = wp_trim_words( $give_content, 28, null ) ;
													?>
													<p><?php echo (isset($give_content) ? $content : '') ?></p>
													<a class="read-more" href="<?php echo the_permalink() ?>"><?php echo esc_html('Read More', 'forgood') ?></a>
												</div>							
											</div>
											<div class="col-md-6">
												<div class="details-right">
													<div class="details-right-progress" style="background: url(<?php echo $src[0] ?>)">
														<?php 
															//progress control class
															if ($progress_bar_value > 90) {
																$add_progress_class = 'add-progress-full';
															}else if ($progress_bar_value < 1){
																$add_progress_class = 'add-progress-start';
															}else {
																$add_progress_class = '';
															}
														?>	
														<?php if(!empty($progress_bar_value)){ ?>
									                        <div class="progress-item <?php echo $add_progress_class ?>" id="progress-running">
									                            <div class="progress-bg">
									                                <div id="progress" class="progress-rate" data-value="<?php echo esc_attr($progress_bar_value); ?>">
									                                	<div class="progress-count-wrap">
									                                		<span class="progress-count counting" data-count="<?php echo esc_attr($progress_bar_value); ?>">0</span>
									                                		<span class="counting-icons">%</span>
									                                	</div>
									                                </div>
									                            </div>
									                        </div>
									                    <?php } ?>
									                    <?php
							                        	if(!empty($fgood_raised || $fgood_goal)) { ?>
							                        		<div class="single-causes-footer">
									                        	<span class="float-left">
									                        		<span><?php echo esc_html('Raised :', 'forgood'); ?></span> 
									                        		<?php echo esc_html($fgood_raised) ?></span>
																<span class="float-right">
																	<span><?php echo esc_html('Goal :', 'forgood'); ?></span> 
																	<?php echo esc_html($fgood_goal) ?></span>
									                        </div>
							                        	<?php }
								                        ?>
								                        <div class="btn-wrap">
									                        <a class="btn btn-white" href="<?php echo the_permalink() ?>"><?php echo esc_html('Donate Now', 'forgood') ?></a>
								                        </div>
							                        </div>
							                        <?php if(!empty($settings['banner-quote'])) : ?>
						                        		<h5 class="text-center mt-3"><?php echo $settings['banner-quote'] ?></h5>
						                        	<?php endif; ?>
												</div>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					<?php endwhile;
				wp_reset_postdata(); endif; ?>
			<?php endif; ?>
		<?php } elseif($settings['banner-style'] == 3){ ?>
			<?php if ( $settings['enable_sticky_3'] == 'yes' ) : 
				$selected_post = new \WP_Query( array(
					'post_type'      => 'give_forms',
					'posts_per_page' => 1,
					'p'              => $settings['select_post_3']
				) );
				
				if ( $selected_post->have_posts() ) :
					while ( $selected_post->have_posts() ) : $selected_post->the_post(); 

						$img_id    = get_post_thumbnail_id( get_the_ID() );
						$src       = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full', false, '' );

						//give control here
						$form  = new \Give_Donate_Form( get_the_ID() );
		                $goal_progress_stats = give_goal_progress_stats( $form );
		                $income = $goal_progress_stats['raw_actual'];
		                $goal   = $goal_progress_stats['raw_goal'];
		                $progress           = $goal ? round( ( $income / $goal ) * 100, 2 ) : 0;
		                $progress_bar_values = $income >= $goal ? 100 : $progress;
		                $sales = $form->get_sales();
		                $sales = ( !empty($sales) ? $sales : 0 );

		                $progress_bar_value = (int)$progress_bar_values;

		                //currency control here
						$form_currency = apply_filters( 'give_goal_form_currency', give_get_currency( get_the_ID() ), get_the_ID() );
		                $income_format_args = apply_filters( 'give_goal_income_format_args', array(
		                    'sanitize' => false,
		                    'currency' => $form_currency,
		                    'decimal'  => false,
		                ), get_the_ID() );
		                $goal_format_args = apply_filters( 'give_goal_amount_format_args', array(
		                    'sanitize' => false,
		                    'currency' => $form_currency,
		                    'decimal'  => false,
		                ), get_the_ID() );
		                $income = give_human_format_large_amount( give_format_amount( $income, $income_format_args ), array( 'currency' => $form_currency ) );
		                $goal   = give_human_format_large_amount( give_format_amount( $goal, $goal_format_args ), array( 'currency' => $form_currency ) );
		                $fgood_raised = give_currency_filter( $income, array( 'form_id' => get_the_ID() ) );
		                $fgood_goal = give_currency_filter( $goal, array( 'form_id' => get_the_ID() ) );
						?>
						<div class="banner-area banner-area-3" style="background: url(<?php echo $src[0] ?>)">
							<div class="container">
								<div class="row">
									<div class="col-lg-6">
										<div class="banner-inner">
                    						<h2><?php the_title(); ?></h2>
                    						<?php
											//progress control content
											$give_content = get_post_meta(get_the_ID(), '_give_form_content', true);
		                    					$content = wp_trim_words( $give_content, 28, null ) ;
											?>
											<p><?php echo (isset($give_content) ? $content : '') ?></p>
											<a class="btn btn-base read-more" href="<?php echo the_permalink() ?>"><?php echo esc_html('Donate For The Causes', 'forgood') ?></a>
										</div>							
									</div>
								</div>
							</div>
						</div>
						<div class="banner-footer bg-yellow">
							<div class="container">
								<div class="row">
									<div class="col-lg-6 col-md-5">
										<div class="details-right">
											<div class="details-right-progress" style="background: url(<?php echo $src[0] ?>)">
												<?php 
													//progress control class
													if ($progress_bar_value > 90) {
														$add_progress_class = 'add-progress-full';
													}else if ($progress_bar_value < 1){
														$add_progress_class = 'add-progress-start';
													}else {
														$add_progress_class = '';
													}
												?>	
												<?php if(!empty($progress_bar_value)){ ?>
							                        <div class="progress-item <?php echo $add_progress_class ?>" id="progress-running">
							                            <div class="progress-bg">
							                                <div id="progress" class="progress-rate" data-value="<?php echo esc_attr($progress_bar_value); ?>">
							                                	<div class="progress-count-wrap">
							                                		<span class="progress-count counting" data-count="<?php echo esc_attr($progress_bar_value); ?>">0</span>
							                                		<span class="counting-icons">%</span>
							                                	</div>
							                                </div>
							                            </div>
							                        </div>
							                    <?php } ?>
							                    <?php
					                        	if(!empty($fgood_raised || $fgood_goal)) { ?>
					                        		<div class="single-causes-footer">
							                        	<span class="float-left">
							                        		<span><?php echo esc_html('Raised :', 'forgood'); ?></span> 
							                        		<?php echo esc_html($fgood_raised) ?></span>
														<span class="float-right">
															<span><?php echo esc_html('Goal :', 'forgood'); ?></span> 
															<?php echo esc_html($fgood_goal) ?></span>
							                        </div>
					                        	<?php }
						                        ?>
					                        </div>
										</div>
									</div>
									<div class="col-lg-5 col-md-7 offset-lg-1 align-self-center mt-3 mt-md-0">
										<div class="media">
											<div class="media-left">
												<img src="<?php echo $src[0] ?>" alt="img">
											</div>
											<div class="media-body align-self-center">
												<h6><?php the_title(); ?></h6>
												<a class="read-more" href="<?php echo the_permalink() ?>"><?php echo esc_html('Read More', 'forgood') ?></a>
											</div>
											<a class="arrow-readmore" href="<?php echo the_permalink() ?>"><i class="fa fa-angle-right"></i></a>
										</div>	
									</div>
								</div>
							</div>
						</div>
					<?php endwhile;
				wp_reset_postdata(); endif; ?>
			<?php endif; ?>
		<?php } elseif($settings['banner-style'] == 4){ ?>
			<?php if ( $settings['enable_sticky_4'] == 'yes' ) : 
				$selected_post = new \WP_Query( array(
					'post_type'      => 'give_forms',
					'posts_per_page' => 1,
					'p'              => $settings['select_post_4']
				) );
				
				if ( $selected_post->have_posts() ) :
					while ( $selected_post->have_posts() ) : $selected_post->the_post(); 

						$img_id    = get_post_thumbnail_id( get_the_ID() );
						$src       = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full', false, '' );

						//give control here
						$form  = new \Give_Donate_Form( get_the_ID() );
		                $goal_progress_stats = give_goal_progress_stats( $form );
		                $income = $goal_progress_stats['raw_actual'];
		                $goal   = $goal_progress_stats['raw_goal'];
		                $progress           = $goal ? round( ( $income / $goal ) * 100, 2 ) : 0;
		                $progress_bar_values = $income >= $goal ? 100 : $progress;
		                $sales = $form->get_sales();
		                $sales = ( !empty($sales) ? $sales : 0 );

		                $progress_bar_value = (int)$progress_bar_values;

		                //currency control here
						$form_currency = apply_filters( 'give_goal_form_currency', give_get_currency( get_the_ID() ), get_the_ID() );
		                $income_format_args = apply_filters( 'give_goal_income_format_args', array(
		                    'sanitize' => false,
		                    'currency' => $form_currency,
		                    'decimal'  => false,
		                ), get_the_ID() );
		                $goal_format_args = apply_filters( 'give_goal_amount_format_args', array(
		                    'sanitize' => false,
		                    'currency' => $form_currency,
		                    'decimal'  => false,
		                ), get_the_ID() );
		                $income = give_human_format_large_amount( give_format_amount( $income, $income_format_args ), array( 'currency' => $form_currency ) );
		                $goal   = give_human_format_large_amount( give_format_amount( $goal, $goal_format_args ), array( 'currency' => $form_currency ) );
		                $fgood_raised = give_currency_filter( $income, array( 'form_id' => get_the_ID() ) );
		                $fgood_goal = give_currency_filter( $goal, array( 'form_id' => get_the_ID() ) );
						?>
						<div class="banner-area banner-area-4" style="background: url(<?php echo $src[0] ?>)">
							<div class="container">
								<div class="row">
									<div class="col-lg-6 align-self-center">
										<div class="banner-inner">
	                						<h2><?php the_title(); ?></h2>
	                						<?php
											//progress control content
											$give_content = get_post_meta(get_the_ID(), '_give_form_content', true);
		                    					$content = wp_trim_words( $give_content, 28, null ) ;
											?>
											<p><?php echo (isset($give_content) ? $content : '') ?></p>
										</div>							
									</div>
									<div class="col-lg-5 offset-lg-1">
										<div class="details-right mt-3 mt-lg-0">
					                        <?php if(!empty($settings['banner-quote-4'])) : ?>
				                        		<p class="quote"><?php echo $settings['banner-quote-4'] ?></p>
				                        	<?php endif; 
				                        	//progress control content
											$give_content_2 = get_post_meta(get_the_ID(), '_give_form_content', true);
		                    					$content_2 = wp_trim_words( $give_content_2, 12, null ) ;
											?>
											<p class="content"><?php echo (isset($give_content_2) ? $content_2 : '') ?></p>
											<?php 
												//progress control class
												if ($progress_bar_value > 90) {
													$add_progress_class = 'add-progress-full';
												}else if ($progress_bar_value < 1){
													$add_progress_class = 'add-progress-start';
												}else {
													$add_progress_class = '';
												}
											?>	
											<?php if(!empty($fgood_raised || $fgood_goal)) { ?>
				                        		<div class="single-causes-footer">
						                        	<div class="d-inline-block mr-5">
						                        		<span class="d-block"><?php echo esc_html('Raised', 'forgood'); ?></span>
						                        		<span class="f-amount d-block"><?php echo esc_html($fgood_raised) ?></span>
						                        	</div>
													<div class="d-inline-block">
														<span class="d-block"><?php echo esc_html('Goal', 'forgood'); ?></span>
														<span class="f-amount d-block"><?php echo esc_html($fgood_goal) ?></span>
													</div>
						                        </div>
					                        <?php } ?>
											<?php if(!empty($progress_bar_value)){ ?>
						                        <div class="progress-item <?php echo $add_progress_class ?>" id="progress-running">
						                            <div class="progress-bg">
						                                <div id="progress" class="progress-rate" data-value="<?php echo esc_attr($progress_bar_value); ?>">
						                                	<div class="progress-count-wrap">
						                                		<span class="progress-count counting" data-count="<?php echo esc_attr($progress_bar_value); ?>">0</span>
						                                		<span class="counting-icons">%</span>
						                                	</div>
						                                </div>
						                            </div>
						                        </div>
						                    <?php } ?>
						                        <div class="btn-wrap">
							                        <a class="btn btn-red w-100" href="<?php echo the_permalink() ?>"><?php echo esc_html('Donate Now', 'forgood') ?></a>
						                        </div>
					                    </div>
									</div>
								</div>
							</div>
						</div>
					<?php endwhile;
				wp_reset_postdata(); endif; ?>
			<?php endif; ?>
		<?php }else { ?>
			<div class="banner-area banner-area-1" style="background: url( <?php echo esc_url( $image_url[0] ); ?> );">
	            <div class="container">
	            	<div class="banner-inner">
		            	<div class="row">
			            	<div class="col-lg-5 align-self-center">
			            		<?php if (!empty($settings['banner-title'])) { ?>
					        		<h2><?php echo esc_html( $settings['banner-title']  ); ?></h2>
					        	<?php } ?>
					        	<a href="https://www.youtube.com/watch?v=WwvNiN2_Jlk" class="video-btn video-play-btn mfp-iframe" tabindex="0"><i class="fa fa-play"></i></a>
					        	<span class="video-play-content">Watching video</span>
			            	</div>
			            	<?php
			            		if (!empty($settings['banner-form'])) { ?>
			            			<div class="col-lg-5 offset-lg-2">
					            		<?php echo do_shortcode($settings['banner-form']); ?>
					            	</div>
			            		<?php }
			            	?>
			            </div>
		            </div>
	            </div>
		    </div>
		<?php }
	}
}
