<?php
namespace Forgood\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Forgood.
* @since 1.0.0
**/
class Fgood_Causes extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'fgood-causes';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Fgood Causes', 'forgood' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-group';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'forgood_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'forgood' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'forgood' ),
			]
		);

		$this->add_control(
			'causes-style',
			[
				'label' => __( 'causes Style', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( 'Causes Grid', 'forgood' ),
					'2' => __( 'Causes Slider', 'forgood' ),
				],
			]
		);

		$this->add_control(
			'causes-column',
			[
				'label' => __( 'causes Column Style', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-4' => __( 'col-lg-4', 'forgood' ),
					'col-lg-6' => __( 'col-lg-6', 'forgood' ),
					'col-lg-3' => __( 'col-lg-3', 'forgood' ),
				],
				'condition' => [
					'causes-style' => '1',
				],
			]
		);

		$this->add_control(
			'post-order',
			[
				'label' => __( 'Post Order', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DSC',
				'options' => [
					'ASC' => __( 'ASC', 'forgood' ),
					'DSC' => __( 'DSC', 'forgood' ),
				],
			]
		);
		$this->add_control(
			'post-limit',
			[
				'label'       => esc_html__( 'Post Limit', 'forgood' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Display', 'forgood' ),
				'default'     => esc_html__('-1','forgood')
			]
		);
		$this->add_control(
			'post-offset',
			[
				'label'       => esc_html__( 'Post Offset', 'forgood' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Offset', 'forgood' ),
				'default'     => esc_html__('0','forgood')
			]
		);
		$this->end_controls_section();


		//causes style grid
		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Grid Style', 'forgood' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'causes-style' => '1',
				],
			]
		);
		//total area style field
		$this->add_control (
			'details',
			[
				'label' => __( 'Details Space', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'details_space',
			[
				'label' => __( 'Details Spacing', 'forgood' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-causes-inner .details' => 'padding: {{SIZE}}{{UNIT}};',
					'(mobile){{WRAPPER}}.single-causes-inner .details' => 'padding: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Content Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-inner .details p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'content_typograph',
		        'label'     => esc_html__( 'Content Typography', 'forgood' ),
		        'selector' => '{{WRAPPER}} .single-causes-inner .details p',
		    ]
		);

		//title style field
		$this->add_control (
			'title_style',
			[
				'label' => __( 'Title Style', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Hover Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-inner .details h5:hover a' => 'color: {{VALUE}};',
				],
			]
		);
		//progress bar style field
		$this->add_control (
			'progress_bar_style',
			[
				'label' => __( 'Progress Bar Style', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'progress_bar_color',
			[
				'label' => __( 'Progress Bar Bg Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-inner .details .progress-item .progress-bg .progress-rate' => 'background: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();

		//causes style slider
		$this->start_controls_section(
			'section_style_slider',
			[
				'label' => esc_html__( 'Slider Style', 'forgood' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'causes-style' => '2',
				],
			]
		);
		//total area style field
		$this->add_control (
			'details_slider',
			[
				'label' => __( 'Details Space', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'details_space_slider',
			[
				'label' => __( 'Details Spacing', 'forgood' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-causes-slider-item .details' => 'padding: {{SIZE}}{{UNIT}};',
					'(mobile){{WRAPPER}}.single-causes-slider-item .details' => 'padding: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'content_color_slider',
			[
				'label' => __( 'Content Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-slider-item .details p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'content_typograph_slider',
		        'label'     => esc_html__( 'Content Typography', 'forgood' ),
		        'selector' => '{{WRAPPER}} .single-causes-slider-item .details p',
		    ]
		);

		//title style field
		$this->add_control (
			'title_style_slider',
			[
				'label' => __( 'Title Style', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'title_color_slider',
			[
				'label' => __( 'Title Hover Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-slider-item .details h4:hover a' => 'color: {{VALUE}};',
				],
			]
		);
		//progress bar style field
		$this->add_control (
			'progress_bar_style_slider',
			[
				'label' => __( 'Progress Bar Style', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'progress_bar_color_slider',
			[
				'label' => __( 'Progress Bar Bg Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-slider-item .details .progress-item .progress-bg .progress-rate' => 'background: {{VALUE}};',
				],
			]
		);
		//progress bar style field
		$this->add_control (
			'btn_style_slider',
			[
				'label' => __( 'Btn Style', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'btn_color_slider',
			[
				'label' => __( 'Btn Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-slider-item .details .btn' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'btn_bg_color_slider',
			[
				'label' => __( 'Btn Bg Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-slider-item .details .btn' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'btn_bg_hover_color_slider',
			[
				'label' => __( 'Btn Hover Bg Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-causes-slider-item .details .btn:hover' => 'background: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display(); 
		$causes_column  = (isset($settings['causes-column']) ? $settings['causes-column'] : 'col-lg-4');  ?>

		<?php global $post; 
		$causes_query = new \WP_Query(array('post_type'=> 'give_forms', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'], 'offset' => $settings['post-offset'] )); ?>

		<?php if($settings['causes-style'] == 2){ ?>

			<div class="causes-carousel">
				<?php if($causes_query->have_posts()) : 

					$i = 1;
					while($causes_query->have_posts()) : $causes_query->the_post(); ?>
						<?php
							if($i % 2 == 0){
								$j = 'style-two';
							}else {
								$j = '';
							}
						?>
						<?php 
							//give control here
							$form  = new \Give_Donate_Form( get_the_ID() );
			                $goal_progress_stats = give_goal_progress_stats( $form );
			                $income = $goal_progress_stats['raw_actual'];
			                $goal   = $goal_progress_stats['raw_goal'];
			                $progress           = $goal ? round( ( $income / $goal ) * 100, 2 ) : 0;
			                $progress_bar_value = $income >= $goal ? 100 : $progress;
			                $sales = $form->get_sales();
			                $sales = ( !empty($sales) ? $sales : 0 );

			                //currency control here
							$form_currency = apply_filters( 'give_goal_form_currency', give_get_currency( get_the_ID() ), get_the_ID() );
			                $income_format_args = apply_filters( 'give_goal_income_format_args', array(
			                    'sanitize' => false,
			                    'currency' => $form_currency,
			                    'decimal'  => false,
			                ), get_the_ID() );
			                $goal_format_args = apply_filters( 'give_goal_amount_format_args', array(
			                    'sanitize' => false,
			                    'currency' => $form_currency,
			                    'decimal'  => false,
			                ), get_the_ID() );
			                $income = give_human_format_large_amount( give_format_amount( $income, $income_format_args ), array( 'currency' => $form_currency ) );
			                $goal   = give_human_format_large_amount( give_format_amount( $goal, $goal_format_args ), array( 'currency' => $form_currency ) );
			                $fgood_raised = give_currency_filter( $income, array( 'form_id' => get_the_ID() ) );
			                $fgood_goal = give_currency_filter( $goal, array( 'form_id' => get_the_ID() ) );
						?>
						<div class="single-causes-item">
							<div class="single-causes-slider-item <?php echo $j ?>">
								<div class="causes-left">
									<div class="thumb-wrap">
										<?php $image_url = get_the_post_thumbnail_url(); ?>
			                        	<div class="thumb" style="background: url( <?php echo esc_url( $image_url ); ?> );"></div>
									</div>
								</div>
								<div class="causes-right align-self-center">
									<div class="details">
										<h4><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h4>
										<?php
											//progress control content
											$give_content = get_post_meta(get_the_ID(), '_give_form_content', true);
	                    					$content = wp_trim_words( $give_content, 12, null ) ;
										?>
										<p><?php echo (isset($give_content) ? $content : '') ?></p>
										<?php 
											//progress control class
											if ($progress_bar_value > 90) {
												$add_progress_class = 'add-progress-full';
											}else if ($progress_bar_value < 1){
												$add_progress_class = 'add-progress-start';
											}else {
												$add_progress_class = '';
											}
										?>	
										<?php if(!empty($progress_bar_value)){ ?>
					                        <div class="progress-item <?php echo $add_progress_class ?>" id="progress-running-<?php echo $i; ?>">
					                            <div class="progress-bg">
					                                <div id="progress-<?php echo $i ?>" class="progress-rate" data-value="<?php echo esc_attr($progress_bar_value); ?>">
					                                	<div class="progress-count-wrap">
					                                		<span class="progress-count counting" data-count="<?php echo esc_attr($progress_bar_value); ?>">0</span>
					                                		<span class="counting-icons">%</span>
					                                	</div>
					                                </div>
					                            </div>
					                        </div>
					                    <?php } ?>
				                        <?php
				                        	if(!empty($fgood_raised || $fgood_goal)) { ?>
				                        		<div class="single-causes-footer">
						                        	<span class="float-left">
						                        		<span><?php echo esc_html('Raised :', 'forgood'); ?></span> 
						                        		<?php echo esc_html($fgood_raised) ?></span>
													<span class="float-right">
														<span><?php echo esc_html('Goal :', 'forgood'); ?></span> 
														<?php echo esc_html($fgood_goal) ?></span>
						                        </div>
				                        	<?php }
				                        ?>
				                        <div class="btn-wrap text-left">
				                        	<a class="btn btn-base-2" href="<?php echo get_the_permalink(); ?>">DONATE FOR THE CAUSE</a>
				                        </div>
									</div>
								</div>
							</div>
		                </div>
					<?php $i++;  endwhile;
					wp_reset_postdata();
				endif; ?>
			</div>

		<?php }else { ?>
			<div class="row justify-content-center">
				<?php if($causes_query->have_posts()) : 

					$i = 1;
					while($causes_query->have_posts()) : $causes_query->the_post(); ?>

						<?php 
							//give control here
							$form  = new \Give_Donate_Form( get_the_ID() );
			                $goal_progress_stats = give_goal_progress_stats( $form );
			                $income = $goal_progress_stats['raw_actual'];
			                $goal   = $goal_progress_stats['raw_goal'];
			                $progress           = $goal ? round( ( $income / $goal ) * 100, 2 ) : 0;
			                $progress_bar_value = $income >= $goal ? 100 : $progress;
			                $sales = $form->get_sales();
			                $sales = ( !empty($sales) ? $sales : 0 );

			                //currency control here
							$form_currency = apply_filters( 'give_goal_form_currency', give_get_currency( get_the_ID() ), get_the_ID() );
			                $income_format_args = apply_filters( 'give_goal_income_format_args', array(
			                    'sanitize' => false,
			                    'currency' => $form_currency,
			                    'decimal'  => false,
			                ), get_the_ID() );
			                $goal_format_args = apply_filters( 'give_goal_amount_format_args', array(
			                    'sanitize' => false,
			                    'currency' => $form_currency,
			                    'decimal'  => false,
			                ), get_the_ID() );
			                $income = give_human_format_large_amount( give_format_amount( $income, $income_format_args ), array( 'currency' => $form_currency ) );
			                $goal   = give_human_format_large_amount( give_format_amount( $goal, $goal_format_args ), array( 'currency' => $form_currency ) );
			                $fgood_raised = give_currency_filter( $income, array( 'form_id' => get_the_ID() ) );
			                $fgood_goal = give_currency_filter( $goal, array( 'form_id' => get_the_ID() ) );
						?>

						<div class="<?php echo $causes_column ?> col-md-6">
		                    <div class="single-causes-inner">
		                        <div class="thumb">
									<?php echo get_the_post_thumbnail( null, 'forgood-causes-thumbnail', array('class'=> 'img-respons') ) ?>
								</div>
								<div class="details">
									<h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
									<?php
										//progress control content
										$give_content = get_post_meta(get_the_ID(), '_give_form_content', true);
                    					$content = wp_trim_words( $give_content, 11, null ) ;
									?>
									<p><?php echo (isset($give_content) ? $content : '') ?></p>
									<?php 
										//progress control class
										if ($progress_bar_value > 90) {
											$add_progress_class = 'add-progress-full';
										}else if ($progress_bar_value < 1){
											$add_progress_class = 'add-progress-start';
										}else {
											$add_progress_class = '';
										}
									?>	

									<?php if(!empty($progress_bar_value)){ ?>
				                        <div class="progress-item <?php echo $add_progress_class ?>" id="progress-running-<?php echo $i; ?>">
				                            <div class="progress-bg">
				                                <div id="progress-<?php echo $i ?>" class="progress-rate" data-value="<?php echo esc_attr($progress_bar_value); ?>">
				                                	<div class="progress-count-wrap">
				                                		<span class="progress-count counting" data-count="<?php echo esc_attr($progress_bar_value); ?>">0</span>
				                                		<span class="counting-icons">%</span>
				                                	</div>
				                                </div>
				                            </div>
				                        </div>
				                    <?php } ?>
			                        <?php
			                        	if(!empty($fgood_raised || $fgood_goal)) { ?>
			                        		<div class="single-causes-footer">
					                        	<span class="float-left">
					                        		<span><?php echo esc_html('Raised :', 'forgood'); ?></span> 
					                        		<?php echo esc_html($fgood_raised) ?></span>
												<span class="float-right">
													<span><?php echo esc_html('Goal :', 'forgood'); ?></span> 
													<?php echo esc_html($fgood_goal) ?></span>
					                        </div>
			                        	<?php }
			                        ?>
								</div>
		                    </div>
		                </div>
		                <?php $i++; 
					endwhile;
					wp_reset_postdata();
				endif; ?>
			</div>
		<?php } ?>
		
	<?php }
}