<?php
namespace Forgood\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Forgood.
* @since 1.0.0
**/
class Fgood_Section_Title extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'fgood-section-title';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Fgood Section Title', 'dominie' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-post-title';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'forgood_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'forgood' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'forgood' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Add Your Title Here', 'forgood' ),
			]
		);
		$this->add_control(
			'content',
			[
				'label' => esc_html__( 'Content', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Add Your Content Here', 'forgood' ),
			]
		);
		$this->add_control(
			'content-2',
			[
				'label' => esc_html__( 'Content 2', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
			]
		);
		$this->add_control(
			'btn-text',
			[
				'label' => esc_html__( 'Btn Text', 'forgood' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'View All Courses', 'forgood' ),
			]
		);
		$this->add_control(
			'btn-url',
			[
				'label' => esc_html__( 'Btn URL', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '#', 'forgood' ),
			]
		);
		$this->add_control(
			'selected_icon',
			[
				'label' => __( 'Icon', 'elementor' ),
				'type' => Controls_Manager::ICONS,
			]
		);
		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'forgood' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'forgood' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'forgood' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'forgood' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'forgood' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}}' => 'text-align: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();


		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'forgood' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'heading_title',
			[
				'label' => __( 'Title', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typograph',
		        'label'     => esc_html__( 'Title Typography', 'mbpcore' ),
		        'selector' => '{{WRAPPER}} .section-title h2',
		    ]
		);

		$this->add_control(
			'heading_content',
			[
				'label' => __( 'Content', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Content Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .content' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content2_color',
			[
				'label' => __( 'Content two Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .content2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'content_typograph',
		        'label'     => esc_html__( 'Content Typography', 'mbpcore' ),
		        'selector' => '{{WRAPPER}} .section-title p',
		    ]
		);

		$this->add_control(
			'heading_btn',
			[
				'label' => __( 'Btn', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'btn_color',
			[
				'label' => __( 'Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .btn' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Bg Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .btn' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'bg_hover_color',
			[
				'label' => __( 'Bg Hover Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .btn:hover' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'btn_typograph',
		        'label'     => esc_html__( 'Btn Typography', 'mbpcore' ),
		        'selector' => '{{WRAPPER}} .section-title .btn',
		    ]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display(); ?>

        <div class="section-title">
        	<?php if (!empty($settings['title'])) { ?>
        		<h2 class="title"><?php echo esc_html( $settings['title']  ); ?></h2>
        	<?php } ?>
        	<?php if (!empty($settings['content'])) { ?>
        		<p class="content"><?php echo esc_html( $settings['content']  ); ?></p>
        	<?php } ?>
        	<?php if (!empty($settings['content-2'])) { ?>
        		<p class="content2"><?php echo esc_html( $settings['content-2']  ); ?></p>
        	<?php } ?>
        	<?php if (!empty($settings['btn-text'])) { ?>
        		<a class="btn btn-base" href="<?php echo esc_url( $settings['btn-url']  ); ?>"><?php echo esc_html( $settings['btn-text']  ); ?></a>
        	<?php } ?>
        </div>
        
	<?php }
}
