<?php
namespace Forgood\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Fgood.
* @since 1.0.0
**/
class Fgood_Testimonial extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'fgood-testimonial';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Fgood Testimonial', 'forgood' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-testimonial';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'forgood_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'forgood' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'forgood' ),
			]
		);
		$this->add_control(
			'content',
			[
				'label' => esc_html__( 'Content', 'forgood' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Después de muchas pruebas en cuanto a velocidad, rendimiento y SEO estamos entusiasmados con Astra. La mejor elección para una empresa que quiera destacar en internet.', 'forgood' ),
			]
		);
		$this->add_control(
	   		'image',
	      	[
	          'label' => esc_html__( 'Image', 'forgood' ),
	          'type'  => Controls_Manager::MEDIA,
				'dynamic' => [
				'active' => true,
			   ],
	    	]
	    );
		$this->add_control(
			'name',
			[
				'label' => esc_html__( 'Name', 'forgood' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Add Your Name Here', 'forgood' ),
			]
		);
		$this->add_control(
			'designation',
			[
				'label' => esc_html__( 'Designation', 'forgood' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Add Your Name Here', 'forgood' ),
			]
		);
		$this->add_control(
			'review',
			[
				'label' => __( 'Review', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => '5',
				'options' => [
					'1' => __( '1 Star', 'forgood' ),
					'2' => __( '2 Star', 'forgood' ),
					'3' => __( '3 Star', 'forgood' ),
					'4' => __( '4 Star', 'forgood' ),
					'5' => __( '5 Star', 'forgood' ),
				],
			]
		);
		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'forgood' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'forgood' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'forgood' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'forgood' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'forgood' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}}' => 'text-align: {{VALUE}};',
				],
			]
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'forgood' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		//color field
		$this->add_responsive_control(
			'bottom_space',
			[
				'label' => __( 'Bottom Spacing', 'forgood' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .section-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					'(mobile){{WRAPPER}} .section-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'sub-title_color',
			[
				'label' => __( 'Sub Title Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .sub-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title-color',
			[
				'label' => __( 'Title Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content-color',
			[
				'label' => __( 'Content Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'btn_color',
			[
				'label' => __( 'Btn Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .btn' => 'background: {{VALUE}};',
				],
			]
		);


		$this->add_control(
			'text_transform',
			[
				'label' => esc_html__( 'Text Transform', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'None', 'forgood' ),
					'uppercase' => esc_html__( 'UPPERCASE', 'forgood' ),
					'lowercase' => esc_html__( 'lowercase', 'forgood' ),
					'capitalize' => esc_html__( 'Capitalize', 'forgood' ),
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display(); 

		$images = $settings['image'];
		$review = $settings['review'];
		$image_id = $settings['image']['id'];
		$image_url = wp_get_attachment_image_src( $image_id, 'full', false ); ?>

        <div class="single-testimonial-inner">
            <div class="ratting-inner">
            	<?php
            		for ($i=0; $i < $settings['review'] ; $i++) { ?>
            			<i class="fa fa-star"></i> 
            		<?php }
            	?>
            </div>
            <?php if (!empty($settings['content'])) { ?>
        		<p class="testimonial-content"><?php echo esc_html( $settings['content']  ); ?></p>
        	<?php } ?>
            <div class="media">
            	<?php if (!empty($images['url'])): ?>
            		<div class="media-left">
                        <img src="<?php echo $images['url'] ?>" alt="img">
                    </div>
            	<?php endif ?>
                <div class="media-body align-self-center">
                	<?php if (!empty($settings['name'])) { ?>
		        		<h6><?php echo esc_html( $settings['name']  ); ?></h6>
		        	<?php } ?>
		        	<?php if (!empty($settings['designation'])) { ?>
		        		<p class="mb-0"><?php echo esc_html( $settings['designation']  ); ?></p>
		        	<?php } ?>
                </div>
            </div>
        </div>

	<?php }
}
